@@ -20,42 +20,35 @@
    OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. */
 
 #include "sys.h"
-#include "indent.h"
-
 #include <ctype.h>
 #include <stdlib.h>
-
 #if defined (HAVE_UNISTD_H)
 #include <unistd.h>
 #endif
 #include <string.h>
-
 #ifdef VMS
-#   include <file.h>
-#   include <types.h>
-#   include <stat.h>
-#else  /* not VMS */
-
+#include <file.h>
+#include <types.h>
+#include <stat.h>
+#else /* not VMS */
 #include <sys/types.h>
 #include <sys/stat.h>
 /* POSIX says that <fcntl.h> should exist.  Some systems might need to use
    <sys/fcntl.h> or <sys/file.h> instead.  */
 #include <fcntl.h>
-
 #ifdef _WIN32
 #include <io.h>
 #endif
-
 #endif /* not VMS */
+#include "indent.h"
+#include "io.h"
+#include "globs.h"
 
-RCSTAG_CC("$Id: io.c,v 1.15 1999/07/09 00:03:28 carlo Exp $")
-
-extern void free ();
+RCSTAG_CC ("$Id: io.c,v 1.20 1999/07/22 14:15:36 carlo Exp $");
 
 /* number of levels a label is placed to left of code */
 #define LABEL_OFFSET 2
 
-
 /* Stuff that needs to be shared with the rest of indent. Documented in
    indent.h.  */
 char *in_prog;
@@ -65,7 +58,7 @@ unsigned long in_prog_size;
 FILE *output;
 char *buf_ptr;
 char *buf_end;
-int  break_line;
+int break_line;
 int had_eof;
 int out_lines;
 int com_lines;
@@ -74,13 +67,13 @@ int paren_target;
 int suppress_blanklines = 0;
 static int comment_open;
 static int inhibited = 0;
-
 
-INLINE int
+
+int
 count_columns (column, bp, stop_char)
      int column;
      char *bp;
-     char stop_char;
+     int stop_char;
 {
   while (*bp != stop_char && *bp != NULL_CHAR)
     {
@@ -128,20 +121,21 @@ const int boolean_operator = 1;
  *         <--------------------->
  *          priority_code_length
  */
-struct buf_break_st {
-  struct buf_break_st *next;		/* The first possible break point to the right, if any. */
-  struct buf_break_st *prev;		/* The first possible break point to the left, if any. */
-  char *ptr;				/* The break point: the first character in the buffer that will
-  					   not be put on this line any more. */
-  char *corresponds_to;			/* If ptr equals s_code and this equals s_code_corresponds_to,
-  					   then parser_state_toc->procname is valid. */
-  int target_col;			/* Indentation column if we would break the line here. */
+struct buf_break_st
+{
+  struct buf_break_st *next;	/* The first possible break point to the right, if any. */
+  struct buf_break_st *prev;	/* The first possible break point to the left, if any. */
+  char *ptr;			/* The break point: the first character in the buffer that will
+				   not be put on this line any more. */
+  char *corresponds_to;		/* If ptr equals s_code and this equals s_code_corresponds_to,
+				   then parser_state_toc->procname is valid. */
+  int target_col;		/* Indentation column if we would break the line here. */
   int first_level;
-  int level;				/* Number of open '(' and '['. */
-  int col;				/* The number of columns left of the break point, before the break. */
-  int priority_code_length;		/* Used to calculate the priority of this break point: */
+  int level;			/* Number of open '(' and '['. */
+  int col;			/* The number of columns left of the break point, before the break. */
+  int priority_code_length;	/* Used to calculate the priority of this break point: */
   enum bb_code priority_code;
-  int priority_newline;			/* Set when in the input file there was a newline at this place. */
+  int priority_newline;		/* Set when in the input file there was a newline at this place. */
   int priority;
 };
 
@@ -151,14 +145,19 @@ struct buf_break_st *buf_break;
 /*
  * Calculate break priority.
  */
-static void set_priority(struct buf_break_st *bb)
+static void
+set_priority (bb)
+     struct buf_break_st *bb;
 {
   bb->priority = bb->priority_code_length;
   if (bb->priority_code == bb_semicolon)
     bb->priority += 5000;
-  if (bb->priority_code == bb_before_boolean_binary_op || (bb->priority_code == bb_after_boolean_binary_op && bb->priority_code_length > 2))
+  if (bb->priority_code == bb_before_boolean_binary_op
+      || (bb->priority_code == bb_after_boolean_binary_op
+	  && bb->priority_code_length > 2))
     bb->priority += 4000;
-  if (bb->priority_code == bb_after_boolean_binary_op && break_before_boolean_operator)
+  if (bb->priority_code == bb_after_boolean_binary_op
+      && break_before_boolean_operator)
     bb->priority -= 3;
   if (bb->priority_code == bb_after_equal_sign)
     bb->priority += 3000;
@@ -194,43 +193,46 @@ static void set_priority(struct buf_break_st *bb)
  * This is because the `target_col' is pretty close to the break point
  * of the `while': "mask"->target_col - "while"->col == 15 == "mask"->level * 2 + 1.
  */
-static int better_break(struct buf_break_st *b1, const struct buf_break_st *b2)
+static int
+better_break (b1, b2)
+     struct buf_break_st *b1;
+     const struct buf_break_st *b2;
 {
   static int first_level;
   int is_better;
   if (!b2)
-  {
-    first_level = b1->level;
-    b1->first_level = first_level;
-    return 1;
-  }
+    {
+      first_level = b1->level;
+      b1->first_level = first_level;
+      return 1;
+    }
   if (honour_newlines && b2->priority_newline)
     is_better = false;
   else if (honour_newlines && b1->priority_newline)
     is_better = true;
   else
-  {
-    int only_parens_till_b2 = 0;
-    is_better = (b1->priority > b2->priority);
-    if (is_better)
     {
-      char *p;
-      for (p = b2->ptr; p >= s_code; --p)
-      {
-	if (*p == '!')
-	  --p;
-	if (*p != '(')
-	  break;
-      }
-      if (p < s_code)
-        only_parens_till_b2 = 1;
+      int only_parens_till_b2 = 0;
+      is_better = (b1->priority > b2->priority);
+      if (is_better)
+	{
+	  char *p;
+	  for (p = b2->ptr; p >= s_code; --p)
+	    {
+	      if (*p == '!')
+		--p;
+	      if (*p != '(')
+		break;
+	    }
+	  if (p < s_code)
+	    only_parens_till_b2 = 1;
+	}
+      if (lineup_to_parens
+	  && b1->level > first_level + 1
+	  && !(only_parens_till_b2
+	       && b1->target_col <= b2->col + (1 + 2 * b1->level)))
+	is_better = false;
     }
-    if (lineup_to_parens
-	&& b1->level > first_level + 1
-	&& !(only_parens_till_b2
-	     && b1->target_col <= b2->col + (1 + 2 * b1->level)))
-      is_better = false;
-  }
   if (is_better)
     b1->first_level = first_level;
   return is_better;
@@ -240,11 +242,13 @@ static int better_break(struct buf_break_st *b1, const struct buf_break_st *b2)
  * This function is called at every position where we possibly want
  * to break a line (if it gets too long).
  */
-void set_buf_break(enum bb_code code)
+void
+set_buf_break (code)
+     enum bb_code code;
 {
   int target_col, level;
   int code_target = compute_code_target ();
-  struct buf_break_st *bb, *bbi;
+  struct buf_break_st *bb;
 
   /* First, calculate the column that code following e_code would be
      printed in if we'd break the line here.
@@ -256,7 +260,7 @@ void set_buf_break(enum bb_code code)
      by this line break? */
   if (*token == '{')
     target_col -= ind_size;	/* Use `ind_size' because this only happens
-    				   for the first brace of initializer blocks. */
+				   for the first brace of initializer blocks. */
 
   /* Number of open brackets */
   level = parser_state_tos->p_l_follow;
@@ -270,7 +274,7 @@ void set_buf_break(enum bb_code code)
     target_col = 1;
   else if (level == 0)		/* No open brackets? */
     {
-      if (parser_state_tos->in_stmt)		/* Breaking a statement? */
+      if (parser_state_tos->in_stmt)	/* Breaking a statement? */
 	target_col += continuation_indent;
     }
   else if (!lineup_to_parens)
@@ -286,21 +290,22 @@ void set_buf_break(enum bb_code code)
     }
 
   /* Store the position of `e_code' as the place to break this line. */
-  bb = (struct buf_break_st *)xmalloc(sizeof(struct buf_break_st));
+  bb = (struct buf_break_st *) xmalloc (sizeof (struct buf_break_st));
   bb->ptr = e_code;
   bb->level = level;
   bb->target_col = target_col;
   bb->corresponds_to = token;
   *e_code = 0;
-  bb->col = count_columns(code_target, s_code, NULL_CHAR) - 1;
+  bb->col = count_columns (code_target, s_code, NULL_CHAR) - 1;
 
   /* Calculate default priority. */
   bb->priority_code_length = (e_code - s_code);
-  bb->priority_newline = (parser_state_tos->last_saw_nl && !parser_state_tos->broken_at_non_nl);
+  bb->priority_newline = (parser_state_tos->last_saw_nl
+			  && !parser_state_tos->broken_at_non_nl);
   if (buf_break)
     bb->first_level = buf_break->first_level;
   switch (parser_state_tos->last_token)
-  {
+    {
     case binary_op:
       if ((e_code - s_code) >= 3 && e_code[-3] == ' '
 	  && ((e_code[-1] == '&' && e_code[-2] == '&')
@@ -309,56 +314,54 @@ void set_buf_break(enum bb_code code)
       else if (e_code - s_code >= 2
 	       && e_code[-1] == '='
 	       && (e_code[-2] == ' '
-	           || (e_code - s_code >= 3
-                       && e_code[-3] == ' '
-	               && (e_code[-2] == '%'
-	                   || e_code[-2] == '^'
-		           || e_code[-2] == '&'
-		           || e_code[-2] == '*'
-		           || e_code[-2] == '-'
-		           || e_code[-2] == '+'
-		           || e_code[-2] == '|'))))
-        bb->priority_code = bb_after_equal_sign;
+		   || (e_code - s_code >= 3
+		       && e_code[-3] == ' '
+		       && (e_code[-2] == '%'
+			   || e_code[-2] == '^'
+			   || e_code[-2] == '&'
+			   || e_code[-2] == '*'
+			   || e_code[-2] == '-' || e_code[-2] == '+'
+			   || e_code[-2] == '|'))))
+	bb->priority_code = bb_after_equal_sign;
       else if (((e_code - s_code) >= 2
-                && e_code[-2] == ' '
-	        && (e_code[-1] == '<' || e_code[-1] == '>'))
+		&& e_code[-2] == ' '
+		&& (e_code[-1] == '<' || e_code[-1] == '>'))
 	       || ((e_code - s_code) >= 3
-	           && e_code[-3] == ' '
+		   && e_code[-3] == ' '
 		   && e_code[-1] == '='
 		   && (e_code[-2] == '='
-		       || e_code[-2] == '!'
-		       || e_code[-2] == '<'
+		       || e_code[-2] == '!' || e_code[-2] == '<'
 		       || e_code[-2] == '>')))
-        bb->priority_code = bb_comparisation;
+	bb->priority_code = bb_comparisation;
       else if (e_code[-1] == '+' || e_code[-1] == '-')
 	bb->priority_code = bb_operator6;
       else if (e_code[-1] == '*' || e_code[-1] == '/' || e_code[-1] == '%')
 	bb->priority_code = bb_operator5;
       else
-        bb->priority_code = bb_binary_op;
+	bb->priority_code = bb_binary_op;
       break;
     case comma:
       bb->priority_code = bb_comma;
       break;
     default:
       if (code == bb_binary_op
-          && (*token == '&' || *token == '|') && *token == token[1])
+	  && (*token == '&' || *token == '|') && *token == token[1])
 	bb->priority_code = bb_before_boolean_binary_op;
       else if (e_code[-1] == ';')
-        bb->priority_code = bb_semicolon;
+	bb->priority_code = bb_semicolon;
       else
-      {
-	bb->priority_code = code;
-	if (code == bb_struct_delim)	/* . -> .* or ->* */
 	{
-	  if (e_code[-1] == '*')
-	    bb->priority_code = bb_operator4;
-          else
-	    bb->priority_code = bb_operator2;
+	  bb->priority_code = code;
+	  if (code == bb_struct_delim)	/* . -> .* or ->* */
+	    {
+	      if (e_code[-1] == '*')
+		bb->priority_code = bb_operator4;
+	      else
+		bb->priority_code = bb_operator2;
+	    }
 	}
-      }
-  }
-  set_priority(bb);
+    }
+  set_priority (bb);
 
   /* Add buf_break to the list */
   if (buf_break_list)
@@ -370,29 +373,30 @@ void set_buf_break(enum bb_code code)
   if (buf_break && bb->col > max_col)
     return;
 
-  if (!better_break(bb, buf_break))
+  if (!better_break (bb, buf_break))
     return;
 
   /* Found better buf_break.  Get rid of all previous possible breaks. */
   buf_break = bb;
   for (bb = bb->prev; bb;)
-  {
-    struct buf_break_st *obb = bb;
-    bb = bb->prev;
-    free(obb);
-  }
+    {
+      struct buf_break_st *obb = bb;
+      bb = bb->prev;
+      free (obb);
+    }
   buf_break->prev = NULL;
 }
 
-void clear_buf_break_list()
+void
+clear_buf_break_list ()
 {
   struct buf_break_st *bb;
   for (bb = buf_break_list; bb;)
-  {
-    struct buf_break_st *obb = bb;
-    bb = bb->prev;
-    free(obb);
-  }
+    {
+      struct buf_break_st *obb = bb;
+      bb = bb->prev;
+      free (obb);
+    }
   buf_break = buf_break_list = NULL;
   break_line = 0;
 }
@@ -406,34 +410,36 @@ void clear_buf_break_list()
  *            |
  *            new_code_target
  */
-void set_next_buf_break(int prev_code_target, int new_code_target, int offset)
+static void
+set_next_buf_break (prev_code_target, new_code_target, offset)
+     int prev_code_target, new_code_target, offset;
 {
   struct buf_break_st *bb;
 
-  better_break(buf_break, NULL);	/* Reset first_level */
+  better_break (buf_break, NULL);	/* Reset first_level */
 
   if (buf_break_list == buf_break)
-  {
-    clear_buf_break_list();
-    return;
-  }
+    {
+      clear_buf_break_list ();
+      return;
+    }
 
   /* Correct all elements of the remaining buf breaks: */
   for (bb = buf_break_list; bb; bb = bb->prev)
-  {
-    if (bb->target_col > buf_break->target_col)
-      bb->target_col -= ((prev_code_target + offset) - new_code_target);
-    bb->col -= ((prev_code_target + offset) - new_code_target);
-    bb->ptr -= offset;
-    bb->priority_code_length -= offset;
-    bb->first_level = buf_break->first_level;
-    if (!buf_break->priority_newline)
-      bb->priority_newline = false;
-    set_priority(bb);
-    if (bb->prev == buf_break)
-      break;
-  }
-  free(buf_break);
+    {
+      if (bb->target_col > buf_break->target_col)
+	bb->target_col -= ((prev_code_target + offset) - new_code_target);
+      bb->col -= ((prev_code_target + offset) - new_code_target);
+      bb->ptr -= offset;
+      bb->priority_code_length -= offset;
+      bb->first_level = buf_break->first_level;
+      if (!buf_break->priority_newline)
+	bb->priority_newline = false;
+      set_priority (bb);
+      if (bb->prev == buf_break)
+	break;
+    }
+  free (buf_break);
 
   /* Set buf_break to first break in the list */
   buf_break = bb;
@@ -442,23 +448,23 @@ void set_next_buf_break(int prev_code_target, int new_code_target, int offset)
 
   /* Find a better break of the existing breaks */
   for (bb = buf_break; bb; bb = bb->next)
-  {
-    if (bb->col > max_col)
-      continue;
-    if (better_break(bb, buf_break))
     {
-      /* Found better buf_break.  Get rid of all previous possible breaks. */
-      buf_break = bb;
-      for (bb = bb->prev; bb;)
-      {
-	struct buf_break_st *obb = bb;
-	bb = bb->prev;
-	free(obb);
-      }
-      bb = buf_break;
-      buf_break->prev = NULL;
+      if (bb->col > max_col)
+	continue;
+      if (better_break (bb, buf_break))
+	{
+	  /* Found better buf_break.  Get rid of all previous possible breaks. */
+	  buf_break = bb;
+	  for (bb = bb->prev; bb;)
+	    {
+	      struct buf_break_st *obb = bb;
+	      bb = bb->prev;
+	      free (obb);
+	    }
+	  bb = buf_break;
+	  buf_break->prev = NULL;
+	}
     }
-  }
 }
 
 #ifdef VMS
@@ -472,30 +478,30 @@ void set_next_buf_break(int prev_code_target, int new_code_target, int offset)
 int
 vms_read (int file_desc, char *buffer, int nbytes)
 {
-    char *bufp;
-    int nread, nleft;
+  char *bufp;
+  int nread, nleft;
 
-    bufp  = buffer;
-    nread = 0;
-    nleft = nbytes;
+  bufp = buffer;
+  nread = 0;
+  nleft = nbytes;
 
-    nread = read (file_desc, bufp, nleft);
-    while (nread > 0)
-      {
-        bufp += nread;
-        nleft -= nread;
-        if (nleft < 0)
-	  fatal ("Internal buffering error");
-	nread = read (file_desc, bufp, nleft);
-      }
+  nread = read (file_desc, bufp, nleft);
+  while (nread > 0)
+    {
+      bufp += nread;
+      nleft -= nread;
+      if (nleft < 0)
+	fatal ("Internal buffering error");
+      nread = read (file_desc, bufp, nleft);
+    }
 
-    return nbytes - nleft;
+  return nbytes - nleft;
 }
 #endif /* VMS */
 
 /* Return the column we are at in the input line. */
 
-INLINE int
+int
 current_column ()
 {
   char *p;
@@ -546,10 +552,10 @@ current_column ()
    the line is currently in column CURRENT_COLUMN.  Returns the ending
    column. */
 
-INLINE int
+static int
 pad_output (current_column, target_column)
-  int current_column;
-  int target_column;
+     int current_column;
+     int target_column;
 {
   if (current_column >= target_column)
     return current_column;
@@ -576,15 +582,12 @@ pad_output (current_column, target_column)
   return current_column;
 }
 
-/* Points to the current input buffer */
-extern struct file_buffer *current_input;
-INLINE void fill_buffer ();
-
 static int prev_target_col_break;
-static int buf_break_used;
+int buf_break_used;
 
 void
-dump_line (int force_nl)
+dump_line (force_nl)
+     int force_nl;
 {				/* dump_line is the routine that actually
 				   effects the printing of the new source. It
 				   prints the label section, followed by the
@@ -597,18 +600,18 @@ dump_line (int force_nl)
   int target_col_break = -1;
 
   if (buf_break_used)
-  {
-    buf_break_used = 0;
-    target_col_break = prev_target_col_break;
-  }
+    {
+      buf_break_used = 0;
+      target_col_break = prev_target_col_break;
+    }
   else if (force_nl)
     parser_state_tos->broken_at_non_nl = false;
 
   if (parser_state_tos->procname[0]
       && s_code_corresponds_to == parser_state_tos->procname)
-  {
-    parser_state_tos->procname = "\0";
-  }
+    {
+      parser_state_tos->procname = "\0";
+    }
 
   /* A blank line */
   if (s_code == e_code && s_lab == e_lab && s_com == e_com)
@@ -635,8 +638,7 @@ dump_line (int force_nl)
     {
       suppress_blanklines = 0;
       parser_state_tos->bl_line = false;
-      if (prefix_blankline_requested
-	  && not_first_line
+      if (prefix_blankline_requested && not_first_line
 	  && n_real_blanklines == 0)
 	n_real_blanklines = 1;
       else if (swallow_optional_blanklines && n_real_blanklines > 1)
@@ -678,16 +680,14 @@ dump_line (int force_nl)
 		    fprintf (output, (tabsize > 1 ? "\t%.*s" : "  %.*s"),
 			     e_lab - s, s);
 		  else
-		    fprintf (output, (tabsize > 1
-				      ? "\t/* %.*s */"
-				      : "  /* %.*s */"),
+		    fprintf (output,
+			     (tabsize > 1 ? "\t/* %.*s */" : "  /* %.*s */"),
 			     e_lab - s, s);
 		}
 	    }
 	  else
 	    fprintf (output, "%.*s", (int) (e_lab - s_lab), s_lab);
-	  cur_col = count_columns (cur_col, s_lab,
-				   NULL_CHAR);
+	  cur_col = count_columns (cur_col, s_lab, NULL_CHAR);
 	}
       else
 	cur_col = 1;		/* there is no label section */
@@ -723,8 +723,8 @@ dump_line (int force_nl)
 	     usual amount.  */
 	  if (parser_state_tos->last_token == lparen)
 	    {
-	      parser_state_tos->paren_indents[parser_state_tos->p_l_follow - 1]
-		+= ind_size - 1;
+	      parser_state_tos->paren_indents[parser_state_tos->p_l_follow -
+					      1] += ind_size - 1;
 	    }
 
 	  cur_col = pad_output (cur_col, target_col);
@@ -735,25 +735,25 @@ dump_line (int force_nl)
 	      char c;
 	      char *ptr = buf_break->ptr;
 
-              if (*ptr != ' ')
-	        --ptr;
+	      if (*ptr != ' ')
+		--ptr;
 
 	      /* Add target_col (and negate) the brackets that are
 	         actually printed.  The remaining brackets must
-		 be given an offset of . */
+	         be given an offset of . */
 	      offset = ptr - s_code + 1;
 
 	      for (i = 0; i < parser_state_tos->p_l_follow; i++)
 		if (parser_state_tos->paren_indents[i] >= 0)
-		{
-		  if (parser_state_tos->paren_indents[i] < ptr - s_code)
-		    parser_state_tos->paren_indents[i]
-		      = -(parser_state_tos->paren_indents[i] + target_col);
-                  else
-		    parser_state_tos->paren_indents[i] -= offset;
-	        }
-              for (i = parser_state_tos->p_l_follow;
-	           i < parser_state_tos->paren_indents_size; ++i)
+		  {
+		    if (parser_state_tos->paren_indents[i] < ptr - s_code)
+		      parser_state_tos->paren_indents[i]
+			= -(parser_state_tos->paren_indents[i] + target_col);
+		    else
+		      parser_state_tos->paren_indents[i] -= offset;
+		  }
+	      for (i = parser_state_tos->p_l_follow;
+		   i < parser_state_tos->paren_indents_size; ++i)
 		if (parser_state_tos->paren_indents[i] >= (ptr - s_code))
 		  parser_state_tos->paren_indents[i] -= offset;
 
@@ -772,7 +772,7 @@ dump_line (int force_nl)
 #if COLOR_DEBUG
 	      fputs (" \e[31m", output);
 	      for (p = s_code; p < e_code; p++)
-	        putc (*p, output);
+		putc (*p, output);
 	      fputs (" \e[0m", output);
 #endif
 	      *e_code = '\0';
@@ -780,9 +780,10 @@ dump_line (int force_nl)
 	      prev_target_col_break = buf_break->target_col;
 	      if (!buf_break->priority_newline)
 		parser_state_tos->broken_at_non_nl = true;
-	      set_next_buf_break(target_col, buf_break->target_col, offset);
+	      set_next_buf_break (target_col, buf_break->target_col, offset);
 	      buf_break_used = 1;
-	      break_line = (buf_break != NULL) && (output_line_length () > max_col);
+	      break_line = (buf_break != NULL)
+		&& (output_line_length () > max_col);
 	    }
 	  else
 	    {
@@ -794,29 +795,29 @@ dump_line (int force_nl)
 	      for (p = s_code; p < e_code; p++)
 		putc (*p, output);
 	      cur_col = count_columns (cur_col, s_code, NULL_CHAR);
-	      clear_buf_break_list();
+	      clear_buf_break_list ();
 	    }
 	}
 
       if (s_com != e_com)
 	{
-	    {
-	      /* Here for comment printing. */
-	      int target = parser_state_tos->com_col;
-	      char *com_st = s_com;
+	  {
+	    /* Here for comment printing. */
+	    int target = parser_state_tos->com_col;
+	    char *com_st = s_com;
 
-	      if (cur_col > target)
-		{
-		  putc (EOL, output);
-		  cur_col = 1;
-		  ++out_lines;
-		}
+	    if (cur_col > target)
+	      {
+		putc (EOL, output);
+		cur_col = 1;
+		++out_lines;
+	      }
 
-	      cur_col = pad_output (cur_col, target);
-	      fwrite (com_st, e_com - com_st, 1, output);
-	      cur_col += e_com - com_st;
-	      com_lines++;
-	    }
+	    cur_col = pad_output (cur_col, target);
+	    fwrite (com_st, e_com - com_st, 1, output);
+	    cur_col += e_com - com_st;
+	    com_lines++;
+	  }
 	}
       else if (embedded_comment_on_line)
 	com_lines++;
@@ -854,33 +855,32 @@ dump_line (int force_nl)
   parser_state_tos->ind_stmt = parser_state_tos->in_stmt;
 
   parser_state_tos->dumped_decl_indent = 0;
-  *(e_lab  = s_lab) = '\0';	/* reset buffers */
+  *(e_lab = s_lab) = '\0';	/* reset buffers */
   if (not_truncated)
     {
       *(e_code = s_code) = '\0';
       s_code_corresponds_to = NULL;
     }
 
-  *(e_com  = s_com) = '\0';
+  *(e_com = s_com) = '\0';
   parser_state_tos->ind_level = parser_state_tos->i_l_follow;
   parser_state_tos->paren_level = parser_state_tos->p_l_follow;
   if (parser_state_tos->paren_level > 0)
     {
       /* If we broke the line and the following line will
-	 begin with a rparen, the indentation is set for
-	 the column of the rparen *before* the break - reset
-	 the column to the position after the break. */
-      if (! not_truncated && (*s_code == '(' || *s_code == '[')
+         begin with a rparen, the indentation is set for
+         the column of the rparen *before* the break - reset
+         the column to the position after the break. */
+      if (!not_truncated && (*s_code == '(' || *s_code == '[')
 	  && parser_state_tos->paren_level >= 2)
 	{
-	  paren_target = -parser_state_tos->paren_indents[parser_state_tos->paren_level - 2];
-#if 0
-	  parser_state_tos->paren_indents[parser_state_tos->paren_level - 1]
-	    = parser_state_tos->paren_indents[parser_state_tos->paren_level - 2] - 1;
-#endif
+	  paren_target =
+	    -parser_state_tos->paren_indents[parser_state_tos->paren_level -
+					     2];
 	}
       else
-	paren_target = -parser_state_tos->paren_indents[parser_state_tos->paren_level - 1];
+	paren_target =
+	  -parser_state_tos->paren_indents[parser_state_tos->paren_level - 1];
     }
   else
     paren_target = 0;
@@ -898,8 +898,7 @@ dump_line (int force_nl)
 	{
 	  while (*p != '\0' && *p != EOL)
 	    putc (*p++, output);
-	  if (*p == '\0'
-	      && (p - current_input->data) == current_input->size)
+	  if (*p == '\0' && (p - current_input->data) == current_input->size)
 	    {
 	      buf_ptr = buf_end = in_prog_pos = p;
 	      had_eof = 1;
@@ -907,22 +906,22 @@ dump_line (int force_nl)
 	    }
 
 	  if (*p == EOL)
-            {
+	    {
 	      cur_line = p + 1;
-              line_no++;
-            }
+	      line_no++;
+	    }
 	  putc (*p++, output);
 	  while (*p == ' ' || *p == TAB)
 	    putc (*p++, output);
 	  if (*p == '/' && (*(p + 1) == '*' || *(p + 1) == '/'))
 	    {
 	      /* We've hit a comment.  See if turns formatting
-		 back on. */
+	         back on. */
 	      putc (*p++, output);
 	      putc (*p++, output);
 	      while (*p == ' ' || *p == TAB)
 		putc (*p++, output);
-	      if (! strncmp (p, "*INDENT-ON*", 11))
+	      if (!strncmp (p, "*INDENT-ON*", 11))
 		{
 		  do
 		    {
@@ -941,7 +940,7 @@ dump_line (int force_nl)
 			    {
 			      inhibited = 0;
 			      cur_line = p + 1;
-              		      line_no++;
+			      line_no++;
 			    }
 			  putc (*p++, output);
 			}
@@ -951,15 +950,15 @@ dump_line (int force_nl)
 	    }
 	}
       while (inhibited);
-      
+
       buf_ptr = buf_end = in_prog_pos = cur_line;
       fill_buffer ();
     }
 
   /* Output the rest already if we really wanted a new-line after this code. */
   if (buf_break_used && s_code != e_code && force_nl)
-    dump_line(true);
-     
+    dump_line (true);
+
   return;
 }
 
@@ -969,7 +968,7 @@ int
 compute_code_target ()
 {
   int target_col;
- 
+
   if (buf_break_used)
     return prev_target_col_break;
 
@@ -977,22 +976,22 @@ compute_code_target ()
       && s_code_corresponds_to == parser_state_tos->procname)
     {
       target_col = 1;
-      if (! parser_state_tos->paren_level)
-        return target_col;
+      if (!parser_state_tos->paren_level)
+	return target_col;
     }
   else
     target_col = parser_state_tos->ind_level + 1;
 
-  if (! parser_state_tos->paren_level)
+  if (!parser_state_tos->paren_level)
     {
       if (parser_state_tos->ind_stmt)
 	target_col += continuation_indent;
       return target_col;
     }
 
-  if (! lineup_to_parens)
+  if (!lineup_to_parens)
     return target_col + continuation_indent
-        + (paren_indent * (parser_state_tos->paren_level - 1));
+      + (paren_indent * (parser_state_tos->paren_level - 1));
 
   return paren_target;
 }
@@ -1003,9 +1002,7 @@ compute_label_target ()
   return
     (parser_state_tos->pcase
      ? parser_state_tos->cstk[parser_state_tos->tos] + 1
-     : (*s_lab == '#'
-	? 1
-	: parser_state_tos->ind_level - LABEL_OFFSET + 1));
+     : (*s_lab == '#' ? 1 : parser_state_tos->ind_level - LABEL_OFFSET + 1));
 }
 
 /* VMS defines it's own read routine, `vms_read' */
@@ -1056,9 +1053,9 @@ read_file (filename)
 
   size = INDENT_SYS_READ (fd, fileptr.data, fileptr.size);
 #ifdef __MSDOS__
-  if (size == 0xffff) /* -1 = 0xffff in 16-bit world */
+  if (size == 0xffff)		/* -1 = 0xffff in 16-bit world */
 #else
-  if (size < 0)
+  if (size == (unsigned int)-1)
 #endif
     fatal ("Error reading input file %s", filename);
   if (close (fd) < 0)
@@ -1186,7 +1183,7 @@ fill_buffer ()
 	p++;
 
       /* If we are looking at the beginning of a comment, see
-	 if it turns off formatting with off-on directives. */
+         if it turns off formatting with off-on directives. */
       if (*p == '/' && (*(p + 1) == '*' || *(p + 1) == '/'))
 	{
 	  p += 2;
@@ -1194,7 +1191,7 @@ fill_buffer ()
 	    p++;
 
 	  /* Skip all lines between the indent off and on directives. */
-	  if (! strncmp (p, "*INDENT-OFF*", 12))
+	  if (!strncmp (p, "*INDENT-OFF*", 12))
 	    inhibited = 1;
 	}
 
@@ -1226,7 +1223,7 @@ fill_buffer ()
   buf_ptr = cur_line;
   buf_end = in_prog_pos;
   if (buf_break && (buf_break->ptr >= e_code || buf_break->ptr <= s_code))
-    clear_buf_break_list();
+    clear_buf_break_list ();
 }
 
 #ifdef DEBUG
@@ -1235,4 +1232,5 @@ dump_debug_line ()
 {
   fprintf (output, "\n*** Debug output marker line ***\n");
 }
+
 #endif
